package dev.kske.chess.game.ai;

import dev.kske.chess.board.Move;

/**
 * Contains information about a move search performed by a chess engine.
 * <br>
 * Project: <strong>Chess</strong><br>
 * File: <strong>ProcessingResult.java</strong><br>
 * Created: <strong>08.07.2019</strong><br>
 *
 * @since Chess v0.1-alpha
 * @author Kai S. K. Engelbart
 */
public class ProcessingResult {

	/**
	 * The best move found by the search
	 */
	public final Move move;

	/**
	 * The score associated with the best move
	 */
	public final int score;

	/**
	 * Creates an instance of {@link ProcessingResult}.
	 *
	 * @param move  the best move found by the search
	 * @param score the score associated with the best move
	 */
	public ProcessingResult(Move move, int score) {
		this.move = move;
		this.score = score;
	}

	@Override
	public String toString() {
		return String
			.format("ProcessingResult[Move = %s,Score = %d]", move, score);
	}
}
